<p align="center">
  <img src="https://github.com/cracknuts-team/cracknuts/blob/main/docs/static/logo.svg" alt=""/>
</p>

<p align="center">
    <a href="https://pypi.org/project/cracknuts/"><img src="https://img.shields.io/pypi/v/cracknuts.svg" /></a>
    <a href="https://github.com/cracknuts-team/cracknuts/blob/main/LICENSE"><img src="https://img.shields.io/github/license/cracknuts-team/cracknuts.svg" /></a>
    <a href="https://github.com/cracknuts-team/cracknuts/releases"><img alt="GitHub release" src="https://img.shields.io/github/release/cracknuts-team/cracknuts.svg"></a>
</p>

A library for `cracknuts` device.  

## Install

Just run `pip install cracknuts` or run `pip install cracknuts[jupyter]` if you are developing in [Jupyter](https://jupyter.org/).

Then run `cracknuts --version`, and it will print the version of `cracknuts`.
Congratulations, the installation was successful, and you can now start using `CrackNuts` for research and learning.

## Usage

Visit [CrackNuts](https://cracknuts.io) More details.  
